# pygindex

Python library/framework to access and trade on IG Index

[![PyPI Version][pypi-image]][pypi-url]
[![Build Status][build-image]][build-url]
[![Code Coverage][coverage-image]][coverage-url]
[![Code Quality][quality-image]][quality-url]

<!-- Links -->

[pypi-image]: https://img.shields.io/pypi/v/pygindex
[pypi-url]: https://pypi.org/project/pygindex/
[build-image]: https://github.com/rytis/pygindex/actions/workflows/build.yml/badge.svg
[build-url]: https://github.com/rytis/ppygindex/actions/workflows/build.yml
[coverage-image]: https://codecov.io/gh/rytis/pygindex/branch/main/graph/badge.svg
[coverage-url]: https://codecov.io/gh/rytis/pygindex
[quality-image]: https://api.codeclimate.com/v1/badges/85717ac8e0612fa5d695/maintainability
[quality-url]: https://codeclimate.com/github/rytis/pygindex
